============
About
============


PyLaymon [#0]_ is a python based package which is used for monitoring and visualizing the layers of a neural network. The motivation behind the project was to implement a tool that assists developers envision the different layers of a neural network during the training process. This will aid the developers in better understanding the patterns learned at various layers of the neural network. Hence ease the developers in determining which layers require fine-tuning and improve the outcome expected from the neural network. This will also help developers identify any biases in the network during the training process.

Currently, the package implements the functionality to monitor and visualize the feature maps of a neural network. By default, the feature maps are displayed using the matplotlib library. However one can create their custom display classes. For more information see the Usage tab.

.. [#0] The package only supports the Pytorch framework.
